/****************************************************************************
** Meta object code from reading C++ file 'greeterapp.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kscreenlocker-6.6.5/greeter/greeterapp.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'greeterapp.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ScreenLocker9UnlockAppE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenLocker::UnlockApp::qt_create_metaobjectdata<qt_meta_tag_ZN12ScreenLocker9UnlockAppE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenLocker::UnlockApp",
        "osdProgress",
        "",
        "icon",
        "percent",
        "maximumPercent",
        "additionalText",
        "osdText",
        "handleScreen",
        "QScreen*",
        "screen",
        "createViewForScreen",
        "PlasmaQuick::QuickViewSharedEngine*",
        "resetRequestIgnore",
        "suspendToRam",
        "suspendToDisk",
        "getFocus",
        "markViewsAsVisible",
        "view",
        "graceLockEnded"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'osdProgress'
        QtMocHelpers::SlotData<void(const QString &, int, const int, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 }, { QMetaType::Int, 5 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'osdText'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'handleScreen'
        QtMocHelpers::SlotData<void(QScreen *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'createViewForScreen'
        QtMocHelpers::SlotData<PlasmaQuick::QuickViewSharedEngine *(QScreen *)>(11, 2, QMC::AccessPrivate, 0x80000000 | 12, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'resetRequestIgnore'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'suspendToRam'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'suspendToDisk'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'getFocus'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'markViewsAsVisible'
        QtMocHelpers::SlotData<void(PlasmaQuick::QuickViewSharedEngine *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 18 },
        }}),
        // Slot 'graceLockEnded'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UnlockApp, qt_meta_tag_ZN12ScreenLocker9UnlockAppE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenLocker::UnlockApp::staticMetaObject = { {
    QMetaObject::SuperData::link<QGuiApplication::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker9UnlockAppE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker9UnlockAppE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ScreenLocker9UnlockAppE_t>.metaTypes,
    nullptr
} };

void ScreenLocker::UnlockApp::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UnlockApp *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->osdProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 1: _t->osdText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->handleScreen((*reinterpret_cast<std::add_pointer_t<QScreen*>>(_a[1]))); break;
        case 3: { PlasmaQuick::QuickViewSharedEngine* _r = _t->createViewForScreen((*reinterpret_cast<std::add_pointer_t<QScreen*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<PlasmaQuick::QuickViewSharedEngine**>(_a[0]) = std::move(_r); }  break;
        case 4: _t->resetRequestIgnore(); break;
        case 5: _t->suspendToRam(); break;
        case 6: _t->suspendToDisk(); break;
        case 7: _t->getFocus(); break;
        case 8: _t->markViewsAsVisible((*reinterpret_cast<std::add_pointer_t<PlasmaQuick::QuickViewSharedEngine*>>(_a[1]))); break;
        case 9: _t->graceLockEnded(); break;
        default: ;
        }
    }
}

const QMetaObject *ScreenLocker::UnlockApp::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenLocker::UnlockApp::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker9UnlockAppE_t>.strings))
        return static_cast<void*>(this);
    return QGuiApplication::qt_metacast(_clname);
}

int ScreenLocker::UnlockApp::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGuiApplication::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
