/****************************************************************************
** Meta object code from reading C++ file 'ksldapp.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kscreenlocker-6.6.5/ksldapp.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksldapp.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ScreenLocker7KSldAppE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenLocker::KSldApp::qt_create_metaobjectdata<qt_meta_tag_ZN12ScreenLocker7KSldAppE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenLocker::KSldApp",
        "D-Bus Interface",
        "org.kde.ksld.App",
        "aboutToLock",
        "",
        "aboutToStartGreeter",
        "locked",
        "unlocked",
        "lockStateChanged",
        "cleanUp",
        "endGraceTime",
        "solidSuspend",
        "lockScreenShown",
        "LockState",
        "Unlocked",
        "AcquiringLock",
        "Locked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'aboutToLock'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToStartGreeter'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'locked'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unlocked'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lockStateChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cleanUp'
        QtMocHelpers::SlotData<void()>(9, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'endGraceTime'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'solidSuspend'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'lockScreenShown'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'LockState'
        QtMocHelpers::EnumData<enum LockState>(13, 13, QMC::EnumFlags{}).add({
            {   14, LockState::Unlocked },
            {   15, LockState::AcquiringLock },
            {   16, LockState::Locked },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KSldApp, qt_meta_tag_ZN12ScreenLocker7KSldAppE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ScreenLocker::KSldApp::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker7KSldAppE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker7KSldAppE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ScreenLocker7KSldAppE_t>.metaTypes,
    nullptr
} };

void ScreenLocker::KSldApp::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KSldApp *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->aboutToLock(); break;
        case 1: _t->aboutToStartGreeter(); break;
        case 2: _t->locked(); break;
        case 3: _t->unlocked(); break;
        case 4: _t->lockStateChanged(); break;
        case 5: _t->cleanUp(); break;
        case 6: _t->endGraceTime(); break;
        case 7: _t->solidSuspend(); break;
        case 8: _t->lockScreenShown(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KSldApp::*)()>(_a, &KSldApp::aboutToLock, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSldApp::*)()>(_a, &KSldApp::aboutToStartGreeter, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSldApp::*)()>(_a, &KSldApp::locked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSldApp::*)()>(_a, &KSldApp::unlocked, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSldApp::*)()>(_a, &KSldApp::lockStateChanged, 4))
            return;
    }
}

const QMetaObject *ScreenLocker::KSldApp::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenLocker::KSldApp::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker7KSldAppE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScreenLocker::KSldApp::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ScreenLocker::KSldApp::aboutToLock()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ScreenLocker::KSldApp::aboutToStartGreeter()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ScreenLocker::KSldApp::locked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ScreenLocker::KSldApp::unlocked()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ScreenLocker::KSldApp::lockStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
