/****************************************************************************
** Meta object code from reading C++ file 'screensaveradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "screensaveradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'screensaveradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ScreenSaverAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenSaverAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN18ScreenSaverAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenSaverAdaptor",
        "D-Bus Interface",
        "org.freedesktop.ScreenSaver",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.ScreenSaver\">\n    <signal na"
        "me=\"ActiveChanged\">\n      <arg type=\"b\"/>\n    </signal>\n   "
        " <method name=\"Lock\"/>\n    <method name=\"SimulateUserActivity\""
        "/>\n    <method name=\"GetActive\">\n      <arg direction=\"out\" "
        "type=\"b\"/>\n    </method>\n    <method name=\"GetActiveTime\">\n"
        "      <arg direction=\"out\" type=\"u\" name=\"seconds\"/>\n    </"
        "method>\n    <method name=\"GetSessionIdleTime\">\n      <arg dire"
        "ction=\"out\" type=\"u\" name=\"seconds\"/>\n    </method>\n    <m"
        "ethod name=\"SetActive\">\n      <arg direction=\"out\" type=\"b\""
        "/>\n      <arg direction=\"in\" type=\"b\" name=\"e\"/>\n    </met"
        "hod>\n    <method name=\"Inhibit\">\n      <arg direction=\"in\" t"
        "ype=\"s\" name=\"application_name\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"reason_for_inhibit\"/>\n      <arg direction=\""
        "out\" type=\"u\" name=\"cookie\"/>\n    </method>\n    <method nam"
        "e=\"UnInhibit\">\n      <arg direction=\"in\" type=\"u\" name=\"co"
        "okie\"/>\n    </method>\n    <method name=\"Throttle\">\n      <ar"
        "g direction=\"in\" type=\"s\" name=\"application_name\"/>\n      <"
        "arg direction=\"in\" type=\"s\" name=\"reason_for_inhibit\"/>\n   "
        "   <arg direction=\"out\" type=\"u\" name=\"cookie\"/>\n    </meth"
        "od>\n    <method name=\"UnThrottle\">\n      <arg direction=\"in\""
        " type=\"u\" name=\"cookie\"/>\n    </method>\n  </interface>\n",
        "ActiveChanged",
        "",
        "in0",
        "GetActive",
        "GetActiveTime",
        "GetSessionIdleTime",
        "Inhibit",
        "application_name",
        "reason_for_inhibit",
        "Lock",
        "SetActive",
        "e",
        "SimulateUserActivity",
        "Throttle",
        "UnInhibit",
        "cookie",
        "UnThrottle"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ActiveChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'GetActive'
        QtMocHelpers::SlotData<bool()>(8, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'GetActiveTime'
        QtMocHelpers::SlotData<uint()>(9, 6, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'GetSessionIdleTime'
        QtMocHelpers::SlotData<uint()>(10, 6, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'Inhibit'
        QtMocHelpers::SlotData<uint(const QString &, const QString &)>(11, 6, QMC::AccessPublic, QMetaType::UInt, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'Lock'
        QtMocHelpers::SlotData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetActive'
        QtMocHelpers::SlotData<bool(bool)>(15, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'SimulateUserActivity'
        QtMocHelpers::SlotData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Throttle'
        QtMocHelpers::SlotData<uint(const QString &, const QString &)>(18, 6, QMC::AccessPublic, QMetaType::UInt, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'UnInhibit'
        QtMocHelpers::SlotData<void(uint)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 20 },
        }}),
        // Slot 'UnThrottle'
        QtMocHelpers::SlotData<void(uint)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ScreenSaverAdaptor, qt_meta_tag_ZN18ScreenSaverAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ScreenSaverAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ScreenSaverAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ScreenSaverAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ScreenSaverAdaptorE_t>.metaTypes,
    nullptr
} };

void ScreenSaverAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenSaverAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ActiveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: { bool _r = _t->GetActive();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { uint _r = _t->GetActiveTime();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 3: { uint _r = _t->GetSessionIdleTime();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 4: { uint _r = _t->Inhibit((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->Lock(); break;
        case 6: { bool _r = _t->SetActive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->SimulateUserActivity(); break;
        case 8: { uint _r = _t->Throttle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->UnInhibit((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 10: _t->UnThrottle((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScreenSaverAdaptor::*)(bool )>(_a, &ScreenSaverAdaptor::ActiveChanged, 0))
            return;
    }
}

const QMetaObject *ScreenSaverAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenSaverAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ScreenSaverAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int ScreenSaverAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void ScreenSaverAdaptor::ActiveChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
