/* Generated by wayland-scanner 1.25.0 */

#include <stdbool.h>
#include <stdlib.h>
#include <stdint.h>
#include "wayland-util.h"


static const struct wl_interface *ksld_types[] = {
	NULL,
	NULL,
	NULL,
};

static const struct wl_message org_kde_ksld_requests[] = {
	{ "x11window", "u", ksld_types + 0 },
	{ "suspendSystem", "3", ksld_types + 0 },
	{ "hibernateSystem", "3", ksld_types + 0 },
};

static const struct wl_message org_kde_ksld_events[] = {
	{ "osdProgress", "2sis", ksld_types + 0 },
	{ "osdText", "2ss", ksld_types + 0 },
	{ "canSuspendSystem", "3u", ksld_types + 0 },
	{ "canHibernateSystem", "3u", ksld_types + 0 },
};

WL_EXPORT const struct wl_interface org_kde_ksld_interface = {
	"org_kde_ksld", 3,
	3, org_kde_ksld_requests,
	4, org_kde_ksld_events,
};

