/****************************************************************************
** Meta object code from reading C++ file 'kcm.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kscreenlocker-6.6.5/kcm/kcm.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcm.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ScreenLockerKcmE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenLockerKcm::qt_create_metaobjectdata<qt_meta_tag_ZN15ScreenLockerKcmE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenLockerKcm",
        "currentWallpaperChanged",
        "",
        "defaultsCalled",
        "isDefaultsAppearanceChanged",
        "loadCalled",
        "load",
        "save",
        "defaults",
        "updateState",
        "forceUpdateState",
        "availableWallpaperPlugins",
        "QList<WallpaperInfo>",
        "settings",
        "KScreenSaverSettings*",
        "wallpaperConfiguration",
        "KConfigPropertyMap*",
        "shellConfiguration",
        "shellConfigFile",
        "QUrl",
        "wallpaperConfigFile",
        "wallpaperIntegration",
        "ScreenLocker::WallpaperIntegration*",
        "currentWallpaper",
        "isDefaultsAppearance"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentWallpaperChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultsCalled'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isDefaultsAppearanceChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadCalled'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'defaults'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateState'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'forceUpdateState'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'availableWallpaperPlugins'
        QtMocHelpers::MethodData<QList<WallpaperInfo>()>(11, 2, QMC::AccessPublic, 0x80000000 | 12),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'settings'
        QtMocHelpers::PropertyData<KScreenSaverSettings*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'wallpaperConfiguration'
        QtMocHelpers::PropertyData<KConfigPropertyMap*>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'shellConfiguration'
        QtMocHelpers::PropertyData<KConfigPropertyMap*>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'shellConfigFile'
        QtMocHelpers::PropertyData<QUrl>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'wallpaperConfigFile'
        QtMocHelpers::PropertyData<QUrl>(20, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'wallpaperIntegration'
        QtMocHelpers::PropertyData<ScreenLocker::WallpaperIntegration*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'currentWallpaper'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'isDefaultsAppearance'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenLockerKcm, qt_meta_tag_ZN15ScreenLockerKcmE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenLockerKcm::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ScreenLockerKcmE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ScreenLockerKcmE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ScreenLockerKcmE_t>.metaTypes,
    nullptr
} };

void ScreenLockerKcm::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenLockerKcm *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentWallpaperChanged(); break;
        case 1: _t->defaultsCalled(); break;
        case 2: _t->isDefaultsAppearanceChanged(); break;
        case 3: _t->loadCalled(); break;
        case 4: _t->load(); break;
        case 5: _t->save(); break;
        case 6: _t->defaults(); break;
        case 7: _t->updateState(); break;
        case 8: _t->forceUpdateState(); break;
        case 9: { QList<WallpaperInfo> _r = _t->availableWallpaperPlugins();
            if (_a[0]) *reinterpret_cast<QList<WallpaperInfo>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScreenLockerKcm::*)()>(_a, &ScreenLockerKcm::currentWallpaperChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenLockerKcm::*)()>(_a, &ScreenLockerKcm::defaultsCalled, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenLockerKcm::*)()>(_a, &ScreenLockerKcm::isDefaultsAppearanceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenLockerKcm::*)()>(_a, &ScreenLockerKcm::loadCalled, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KConfigPropertyMap* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KScreenSaverSettings* >(); break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ScreenLocker::WallpaperIntegration* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KScreenSaverSettings**>(_v) = _t->settings(); break;
        case 1: *reinterpret_cast<KConfigPropertyMap**>(_v) = _t->wallpaperConfiguration(); break;
        case 2: *reinterpret_cast<KConfigPropertyMap**>(_v) = _t->shellConfiguration(); break;
        case 3: *reinterpret_cast<QUrl*>(_v) = _t->shellConfigFile(); break;
        case 4: *reinterpret_cast<QUrl*>(_v) = _t->wallpaperConfigFile(); break;
        case 5: *reinterpret_cast<ScreenLocker::WallpaperIntegration**>(_v) = _t->wallpaperIntegration(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->currentWallpaper(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isDefaultsAppearance(); break;
        default: break;
        }
    }
}

const QMetaObject *ScreenLockerKcm::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenLockerKcm::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ScreenLockerKcmE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int ScreenLockerKcm::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void ScreenLockerKcm::currentWallpaperChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ScreenLockerKcm::defaultsCalled()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ScreenLockerKcm::isDefaultsAppearanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ScreenLockerKcm::loadCalled()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
