/****************************************************************************
** Meta object code from reading C++ file 'pamauthenticator.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kscreenlocker-6.6.5/greeter/pamauthenticator.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pamauthenticator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16PamAuthenticatorE_t {};
} // unnamed namespace

template <> constexpr inline auto PamAuthenticator::qt_create_metaobjectdata<qt_meta_tag_ZN16PamAuthenticatorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PamAuthenticator",
        "busyChanged",
        "",
        "promptForSecret",
        "msg",
        "prompt",
        "infoMessage",
        "errorMessage",
        "succeeded",
        "failed",
        "availableChanged",
        "loginFailedDelayStarted",
        "uSecDelay",
        "tryUnlock",
        "respond",
        "response",
        "cancel",
        "busy",
        "available",
        "authenticatorType",
        "NoninteractiveAuthenticatorTypes",
        "unlocked",
        "NoninteractiveAuthenticatorType",
        "None",
        "Fingerprint",
        "Smartcard"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'busyChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'promptForSecret'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'prompt'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'infoMessage'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'errorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'succeeded'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'failed'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loginFailedDelayStarted'
        QtMocHelpers::SignalData<void(const uint)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 12 },
        }}),
        // Slot 'tryUnlock'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'respond'
        QtMocHelpers::SlotData<void(const QByteArray &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 15 },
        }}),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'busy'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'available'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'authenticatorType'
        QtMocHelpers::PropertyData<NoninteractiveAuthenticatorTypes>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'prompt'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'promptForSecret'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'infoMessage'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'errorMessage'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'unlocked'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'NoninteractiveAuthenticatorTypes'
        QtMocHelpers::EnumData<NoninteractiveAuthenticatorTypes>(20, 22, QMC::EnumIsFlag).add({
            {   23, NoninteractiveAuthenticatorType::None },
            {   24, NoninteractiveAuthenticatorType::Fingerprint },
            {   25, NoninteractiveAuthenticatorType::Smartcard },
        }),
    };
    return QtMocHelpers::metaObjectData<PamAuthenticator, qt_meta_tag_ZN16PamAuthenticatorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PamAuthenticator::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PamAuthenticatorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PamAuthenticatorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16PamAuthenticatorE_t>.metaTypes,
    nullptr
} };

void PamAuthenticator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PamAuthenticator *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->busyChanged(); break;
        case 1: _t->promptForSecret((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->prompt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->infoMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->errorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->succeeded(); break;
        case 6: _t->failed(); break;
        case 7: _t->availableChanged(); break;
        case 8: _t->loginFailedDelayStarted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 9: _t->tryUnlock(); break;
        case 10: _t->respond((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 11: _t->cancel(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticator::*)()>(_a, &PamAuthenticator::busyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticator::*)(const QString & )>(_a, &PamAuthenticator::promptForSecret, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticator::*)(const QString & )>(_a, &PamAuthenticator::prompt, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticator::*)(const QString & )>(_a, &PamAuthenticator::infoMessage, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticator::*)(const QString & )>(_a, &PamAuthenticator::errorMessage, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticator::*)()>(_a, &PamAuthenticator::succeeded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticator::*)()>(_a, &PamAuthenticator::failed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticator::*)()>(_a, &PamAuthenticator::availableChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticator::*)(const uint )>(_a, &PamAuthenticator::loginFailedDelayStarted, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isBusy(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isAvailable(); break;
        case 2: QtMocHelpers::assignFlags<NoninteractiveAuthenticatorTypes>(_v, _t->authenticatorType()); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->getPrompt(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->getPromptForSecret(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->getInfoMessage(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->getErrorMessage(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isUnlocked(); break;
        default: break;
        }
    }
}

const QMetaObject *PamAuthenticator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PamAuthenticator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PamAuthenticatorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PamAuthenticator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void PamAuthenticator::busyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PamAuthenticator::promptForSecret(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PamAuthenticator::prompt(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PamAuthenticator::infoMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PamAuthenticator::errorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PamAuthenticator::succeeded()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PamAuthenticator::failed()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PamAuthenticator::availableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PamAuthenticator::loginFailedDelayStarted(const uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
